==> llm-docs-0.1.5.tgz: package/scripts/validate-docs.js <==
#!/usr/bin/env node

/**
 * Documentation Validator
 * 
 * Validates documentation structure, links, and content quality
 * for the federated documentation system.
 *
 * TODO: Implementation tasks:
 * - [ ] Review tests for validation functionality
 * - [ ] Enhance validation with content quality metrics
 * - [ ] Add better reporting and visualization of results
 * - [ ] Implement markdown syntax validation
 * - [ ] Add support for spell checking and grammar checking
 * - [ ] Create visual report of documentation coverage
 * - [ ] Run coverage report to verify 95%+ coverage
 */

const fs = require('fs');
const path = require('path');
const { promisify } = require('util');

const readFile = promisify(fs.readFile);
const readdir = promisify(fs.readdir);
const stat = promisify(fs.stat);

const DOCS_DIR = path.join(__dirname, '../docs');
const REQUIRED_SECTIONS = [
  'getting-started',
  'components',
  'drupal',
  'development',
  'operations',
  'reference'
];

const REQUIRED_FILES = {
  'getting-started': ['README.md', 'installation.md', 'quickstart.md'],
  'components': ['README.md', 'llmcli.md', 'bfapi.md', 'bfagent.md'],
  'drupal': ['README.md', 'installation.md', 'configuration.md', 'recipes.md'],
  'development': ['README.md', 'standards.md', 'testing.md', 'contributing.md'],
  'operations': ['README.md', 'deployment.md', 'monitoring.md', 'security.md'],
  'reference': ['README.md', 'api.md', 'cli.md', 'architecture.md']
};

const VALIDATION_RULES = {
  minFileSize: 100, // bytes
  maxFileSize: 50000, // bytes
  requiredHeaders: ['# ', '## ', '### '],
  forbiddenTerms: [
    'awesome',
    'amazing',
    'incredible',
    'best',
    'perfect',
    'seamless',
    'easy',
    'simple',
    'just',
    'simply'
  ],
  requiredMetadata: ['title', 'description', 'lastUpdated']
};

async function validateDirectory(dir) {
  const errors = [];
  const stats = await stat(dir);
  
  if (!stats.isDirectory()) {
    errors.push(`${dir} is not a directory`);
    return errors;
  }

  const files = await readdir(dir);
  
  // Check required files
  const section = path.basename(dir);
  if (REQUIRED_FILES[section]) {
    for (const requiredFile of REQUIRED_FILES[section]) {
      if (!files.includes(requiredFile)) {
        errors.push(`Missing required file: ${section}/${requiredFile}`);
      }
    }
  }

  // Validate each markdown file
  for (const file of files) {
    if (file.endsWith('.md')) {
      const filePath = path.join(dir, file);
      const fileErrors = await validateFile(filePath);
      errors.push(...fileErrors);
    }
  }

  return errors;
}

async function validateFile(filePath) {
  const errors = [];
  const content = await readFile(filePath, 'utf8');
  const stats = await stat(filePath);

  // Check file size
  if (stats.size < VALIDATION_RULES.minFileSize) {
    errors.push(`${filePath} is too small (${stats.size} bytes)`);
  }
  if (stats.size > VALIDATION_RULES.maxFileSize) {
    errors.push(`${filePath} is too large (${stats.size} bytes)`);
  }

  // Check headers
  const hasRequiredHeaders = VALIDATION_RULES.requiredHeaders.some(header => 
    content.includes(header)
  );
  if (!hasRequiredHeaders) {
    errors.push(`${filePath} is missing required headers`);
  }

  // Check for forbidden terms
  for (const term of VALIDATION_RULES.forbiddenTerms) {
    if (content.toLowerCase().includes(term)) {
      errors.push(`${filePath} contains forbidden term: "${term}"`);
    }
  }

  // Check metadata
  const hasMetadata = VALIDATION_RULES.requiredMetadata.every(field => 
    content.includes(`<!-- ${field}:`)
  );
  if (!hasMetadata) {
    errors.push(`${filePath} is missing required metadata`);
  }

  return errors;
}

async function validateDocs() {
  console.log('Validating documentation...\n');
  
  const errors = [];
  
  // Check required sections
  for (const section of REQUIRED_SECTIONS) {
    const sectionPath = path.join(DOCS_DIR, section);
    if (!fs.existsSync(sectionPath)) {
      errors.push(`Missing required section: ${section}`);
    } else {
      const sectionErrors = await validateDirectory(sectionPath);
      errors.push(...sectionErrors);
    }
  }

  // Report results
  if (errors.length === 0) {
    console.log('✅ Documentation validation passed!');
    process.exit(0);
  } else {
    console.error('❌ Documentation validation failed:');
    errors.forEach(error => console.error(`  - ${error}`));
    process.exit(1);
  }
}

validateDocs().catch(error => {
  console.error('Validation failed:', error);
  process.exit(1);
});

module.exports = { validateDirectory, validateFile, validateDocs };

==> llm-docs-1.0.1.tgz: package/scripts/validate-docs.js <==
#!/usr/bin/env node

/**
 * Documentation Validator
 * 
 * Validates documentation structure, links, and content quality
 * for the federated documentation system.
 *
 * TODO: Implementation tasks:
 * - [ ] Review tests for validation functionality
 * - [ ] Enhance validation with content quality metrics
 * - [ ] Add better reporting and visualization of results
 * - [ ] Implement markdown syntax validation
 * - [ ] Add support for spell checking and grammar checking
 * - [ ] Create visual report of documentation coverage
 * - [ ] Run coverage report to verify 95%+ coverage
 */

const fs = require('fs');
const path = require('path');
const { promisify } = require('util');

const readFile = promisify(fs.readFile);
const readdir = promisify(fs.readdir);
const stat = promisify(fs.stat);

const DOCS_DIR = path.join(__dirname, '../docs');
const REQUIRED_SECTIONS = [
  'getting-started',
  'components',
  'drupal',
  'development',
  'operations',
  'reference'
];

const REQUIRED_FILES = {
  'getting-started': ['README.md', 'installation.md', 'quickstart.md'],
  'components': ['README.md', 'bfcli.md', 'bfapi.md', 'bfagent.md'],
  'drupal': ['README.md', 'installation.md', 'configuration.md', 'recipes.md'],
  'development': ['README.md', 'standards.md', 'testing.md', 'contributing.md'],
  'operations': ['README.md', 'deployment.md', 'monitoring.md', 'security.md'],
  'reference': ['README.md', 'api.md', 'cli.md', 'architecture.md']
};

const VALIDATION_RULES = {
  minFileSize: 100, // bytes
  maxFileSize: 50000, // bytes
  requiredHeaders: ['# ', '## ', '### '],
  forbiddenTerms: [
    'awesome',
    'amazing',
    'incredible',
    'best',
    'perfect',
    'seamless',
    'easy',
    'simple',
    'just',
    'simply'
  ],
  requiredMetadata: ['title', 'description', 'lastUpdated']
};

async function validateDirectory(dir) {
  const errors = [];
  const stats = await stat(dir);
  
  if (!stats.isDirectory()) {
    errors.push(`${dir} is not a directory`);
    return errors;
  }

  const files = await readdir(dir);
  
  // Check required files
  const section = path.basename(dir);
  if (REQUIRED_FILES[section]) {
    for (const requiredFile of REQUIRED_FILES[section]) {
      if (!files.includes(requiredFile)) {
        errors.push(`Missing required file: ${section}/${requiredFile}`);
      }
    }
  }

  // Validate each markdown file
  for (const file of files) {
    if (file.endsWith('.md')) {
      const filePath = path.join(dir, file);
      const fileErrors = await validateFile(filePath);
      errors.push(...fileErrors);
    }
  }

  return errors;
}

async function validateFile(filePath) {
  const errors = [];
  const content = await readFile(filePath, 'utf8');
  const stats = await stat(filePath);

  // Check file size
  if (stats.size < VALIDATION_RULES.minFileSize) {
    errors.push(`${filePath} is too small (${stats.size} bytes)`);
  }
  if (stats.size > VALIDATION_RULES.maxFileSize) {
    errors.push(`${filePath} is too large (${stats.size} bytes)`);
  }

  // Check headers
  const hasRequiredHeaders = VALIDATION_RULES.requiredHeaders.some(header => 
    content.includes(header)
  );
  if (!hasRequiredHeaders) {
    errors.push(`${filePath} is missing required headers`);
  }

  // Check for forbidden terms
  for (const term of VALIDATION_RULES.forbiddenTerms) {
    if (content.toLowerCase().includes(term)) {
      errors.push(`${filePath} contains forbidden term: "${term}"`);
    }
  }

  // Check metadata
  const hasMetadata = VALIDATION_RULES.requiredMetadata.every(field => 
    content.includes(`<!-- ${field}:`)
  );
  if (!hasMetadata) {
    errors.push(`${filePath} is missing required metadata`);
  }

  return errors;
}

async function validateDocs() {
  console.log('Validating documentation...\n');
  
  const errors = [];
  
  // Check required sections
  for (const section of REQUIRED_SECTIONS) {
    const sectionPath = path.join(DOCS_DIR, section);
    if (!fs.existsSync(sectionPath)) {
      errors.push(`Missing required section: ${section}`);
    } else {
      const sectionErrors = await validateDirectory(sectionPath);
      errors.push(...sectionErrors);
    }
  }

  // Report results
  if (errors.length === 0) {
    console.log('✅ Documentation validation passed!');
    process.exit(0);
  } else {
    console.error('❌ Documentation validation failed:');
    errors.forEach(error => console.error(`  - ${error}`));
    process.exit(1);
  }
}

validateDocs().catch(error => {
  console.error('Validation failed:', error);
  process.exit(1);
});

module.exports = { validateDirectory, validateFile, validateDocs };
